| RunPerm | R Documentation |
This function defines the number of permutations (default = 50) and subsequently runs the permutations on an input dataframe. A minimum number of 10 permutations is recommended in order to avoid having very large or very small stability values due to the stochastic nature of the process. On a large dataset, increasing the number of permutations can considerably slow down the analysis.
RunPerm(input, replicates = 50)
input |
Input dataframe (a dataframe object). |
replicates |
Number of permutation replicates to perform (an integer; default replicates=50). |
A dataframe with the output values of the permutation analysis.
data("coral_symbionts")
perm <- RunPerm(input = coral_symbionts,replicates = 50)
perm
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.