coral_symbionts: Coral Symbionts Data

coral_symbiontsR Documentation

Coral Symbionts Data

Description

Example of SAMPLE input. This dataset contains information about coral species and their associated symbionts.

Usage

  data(coral_symbionts)

Format

The first column contains the names of host species, with each row representing a separate sample. Each sample of a single species should have the same name. The remaining columns represent different parasites or symbionts, showing the count of parasites or symbionts present in each individual listed in the first column. If no data is available for an individual, it is denoted as 'NA'.

Bravo, Ben Chehida and van der Meij (2025), supplementary data, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/ece3.70998")}.

References

Bravo, Ben Chehida and van der Meij (2025), \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/ece3.70998")}.

Examples

  # Load the dataset
  data(coral_symbionts)
  head(coral_symbionts)

SAMPLE documentation built on Sept. 15, 2026, 5:09 p.m.