plotstab: Plot

View source: R/plotstab.R

plotstabR Documentation

Plot

Description

This function generates the prevalence rate plots for all the variables in question (e.g. species, habitats).

Usage

plotstab(data, info, outputName = "Results", outputDir = tempdir())

Arguments

data

A dataframe generated by the function RunPerm() (a dataframe object).

info

A dataframe generated by the function stability() (a dataframe object).

outputName

Prefix used for the output (a character; default output_N="Results").

outputDir

Output directory (a character). If omitted, files are generated in the R session's temporary directory.

Value

A text file (.txt) with the output values of the analysis, and a PDF file with the generated plots from the analysis.

Examples

data("coral_symbionts")
set.seed(812)
perm = RunPerm(input = coral_symbionts,replicates = 50)
stable = stability(data = perm,stability_thresh = 5 ,success_points = 5,diff = 2 )
plotstab(data = perm, info = stable, outputName = "Stability_example")
unlink(file.path(tempdir(), "Stability_example.pdf"))
unlink(file.path(tempdir(), "Stability_example.txt"))

SAMPLE documentation built on Sept. 15, 2026, 5:09 p.m.

Related to plotstab in SAMPLE...